/*

 COPYRIGHT AND PERMISSION NOTICE

 Copyright (c) 2004 Claus Broch, Infinite Loop. All rights reserved.

 Permission to use, copy and distribute this software for any purpose
 with or without fee is hereby granted, provided that the above copyright
 notice and this permission notice appear in all copies.

 This Software is provided by Infinite Loop on an "AS IS" basis. INFINITE LOOP
 MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED
 WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE, REGARDING THE INFINITE LOOP SOFTWARE OR ITS USE AND OPERATION ALONE OR
 IN COMBINATION WITH YOUR PRODUCTS.

 IN NO EVENT SHALL INFINITE LOOP BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION, MODIFICATION
 AND/OR DISTRIBUTION OF THE INFINITE LOOP SOFTWARE, HOWEVER CAUSED AND WHETHER 
 UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR 
 OTHERWISE, EVEN IF INFINITE LOOP HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH 
 DAMAGE.

 Except as contained in this notice, the name of the copyright holder shall not
 be used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization of the copyright holder.
 */ 

/*!
    @header ILCrashReporter
 The ILCrashReporter class enables developers to easily integrate crash reporting facilities into existing applications.
 The service is provided by the ILCrashReporter.framework which must be embedded into the application bundles Frameworks folder.<p>
 If the monitored application should crash or otherwise terminate unexpectedly a notification will appear
 allowing the user to provide additional information. If the user then elects to submit the report an email
 is sent directly to the address provided by the developer.
*/

#import <Foundation/Foundation.h>

/*!
    @class ILCrashReporter
    @abstract    Crash reporter task
	@discussion The ILCrashReporter class enables you to launch a background task that will monitor the launching application. If the application
 unexpectedly terminates the crash reporter will display a notification and allow the user to provide a description of the nature of the crash.
 If the user desides to complete the crash report an email is sent containing the users description and the crashlog generated by the operating system.
*/
@interface ILCrashReporter : NSObject
{
	NSTask* _reporterTask;
	NSString* _companyName;
	NSString* _userInfo;
	BOOL _embedFromAddressInEmailSubject;
	
	NSString *httpProtocol;
	NSString *hostName;
	NSInteger port;
	NSString *action;
	NSString *format;
	NSInteger defaultReportAction;
	NSString *defaultReportActionUserPrefBindKeyPath;
	
	NSString *api_key;
	NSString *guid;
	NSString *platform;
	
	NSString *userPrefsPath;
}

// The following methods are the new-skool way to use ILCrashReporter.  Allocate a new instance of ILCrashReporter with [[ILCrashCrashReporter alloc] init], and then use the following methods to set the various properties on it and launch a crash monitoring process.
@property (retain) NSString *httpProtocol;
@property (retain) NSString *hostName;
@property (assign) NSInteger port;
@property (retain) NSString *action;
@property (retain) NSString *format;
@property (assign) NSInteger defaultReportAction;
@property (retain) NSString *defaultReportActionUserPrefBindKeyPath;

@property (retain) NSString *api_key;
@property (retain) NSString *guid;
@property (retain) NSString *platform;

@property (retain) NSString *userPrefsPath;
#ifdef __OBJC2__
@property (copy) NSString* companyName;
@property (copy) NSString* userInfo;
@property BOOL _embedFromAddressInEmailSubject;
#else

// The localized company name that will be displayed to the user in the crash report user interface, e.g. "Realmac Software".
- (NSString*)companyName;
- (void)setCompanyName:(NSString*)value;

// This is an arbitrary string that will be embedded in the crash report email, as a "User Info:" field.  It's useful if you need to specify additional information in the crash report, e.g. a customer's ID number or registration code if you'd like to contact them.
- (NSString*)userInfo;
- (void)setUserInfo:(NSString*)value;

// Embeds the "From: " address into the subject line of the email.  This enables more a useful threaded in certain mail clients (such as Apple Mail).
- (BOOL)embedFromAddressInEmailSubject;
- (void)setEmbedFromAddressInEmailSubject:(BOOL)value;


#endif

/*!
 @method     launchReporterForCompany:reportAddr:
 @abstract   Launch the crash reporter task
 @discussion Launch the crash reporter task.  You should set at least the companyName and reportAddress properties for this to be useful.
 */
- (void)launchReporter;

/*!
 @method     submitManualCrashReport
 @abstract   Submit a "crash report" now to the given report address.
 @discussion This method will display the UI to submit a crash report, even though the application hasn't crashed.  It can be useful to grab the current console log and crash report information for the user.
 */
- (void)submitManualCrashReport;

// The following methods are the old-skool way of using ILCrashReporter.  They're deprecated now because they're simply becoming unweidly to use as more parameters get added.

/*!
    @method defaultReporter
    @abstract   Default ILCrashReporter object
    @discussion Returns the default ILCrashReporter object. You invoke all ILCrashReporter instance methods with this object as the receiver.
	@result	Returns the default ILCrashReporter object or nil on failure
*/
+ (ILCrashReporter*)defaultReporter;


- (void)launchReporterForCompany:(NSString*)company 
					httpProtocol:(NSString *)httpProtocol_ 
						hostName:(NSString *)hostName_ 
							port:(NSInteger)port_ 
						  action:(NSString *)action_ 
						  format:(NSString *)format_
						 api_key:(NSString *)api_key_  
							guid:(NSString *)guid__ 
						platform:(NSString *)platform_  
						userInfo:(NSString*)userInfo 
			 /*defaultReportAction:(NSInteger) defaultReportAction_*/
				   userPrefsPath:(NSString *) userPrefsPath_;

- (void)launchReporter;

/*!
    @method     terminate
    @abstract   Terminate the crash reported task
    @discussion This method will terminate the crash reporter task. You would normally not need to call this method since the crash reporter will automatically terminate when the host application quits normally.
*/
- (void)terminate;

@end
